@@ -113,11 +113,13 @@ class SmartTub:
             raise APIError(e)
 
         if int(r.headers["content-length"]) == 0:
-            return None
-        j = await r.json()
+            ret = None
+        else:
+            ret = await r.json()
 
-        logger.debug(f"{method} {path} successful: {j}")
-        return j
+        logger.debug(f"{method} {path} successful: {ret}")
+
+        return ret
 
     async def get_account(self) -> "Account":
         """Retrieve the SmartTub account of the authenticated user"""
@@ -154,9 +156,6 @@ class Account:
 
 
 class Spa:
-    SecondaryFiltrationMode = Enum(
-        "SecondaryFiltrationMode", "FREQUENT INFREQUENT AWAY"
-    )
     HeatMode = Enum("HeatMode", "ECONOMY DAY AUTO")
     TemperatureFormat = Enum("TemperatureFormat", "FAHRENHEIT CELSIUS")
     EnergyUsageInterval = Enum("EnergyUsageInterval", "DAY MONTH")
@@ -203,6 +202,11 @@ class Spa:
             for reminder_info in (await self.request("GET", "reminders"))["reminders"]
         ]
 
+    async def get_status_full(self) -> "SpaStateFull":
+        """Retrieves the state of lights and pumps in addition to what get_status does."""
+        full_status = await self.request("GET", "fullStatus")
+        return SpaStateFull(self, full_status)
+
     async def get_debug_status(self) -> dict:
         return (await self.request("GET", "debugStatus"))["debugStatus"]
 
@@ -327,6 +331,17 @@ class SpaState:
         return f"<{self.__name__}: {self.properties}>"
 
 
+class SpaStateFull(SpaState):
+    def __init__(self, spa: Spa, state: dict):
+        super().__init__(self, **state)
+        self.lights = [
+            SpaLight(spa, **light_props) for light_props in self.properties["lights"]
+        ]
+        self.pumps = [
+            SpaPump(spa, **pump_props) for pump_props in self.properties["pumps"]
+        ]
+
+
 class SpaWaterState(SpaState):
     def __init__(self, spa: Spa, **properties):
         self.spa = spa
@@ -445,10 +460,16 @@ class SpaReminder:
         self.snoozed = properties["snoozed"]
         self.state = properties["state"]
 
-    # TODO: snoozing
+    async def snooze(self, days: int):
+        body = {"remainingDuration": days}
+        await self.spa.request("PATCH", f"reminders/{self.id}", body)
+
+    async def reset(self, days: int):
+        body = {"remainingDuration": days, "reset": True}
+        await self.spa.request("PATCH", f"reminders/{self.id}", body)
 
     def __str__(self):
-        return f"<SpaReminder {self.id}>"
+        return f"<SpaReminder {self.id}: {self.state}/{self.remaining_days}/{self.snoozed}>"
 
 
 class SpaError:
