@@ -5,10 +5,10 @@ import pytest
 import smarttub
 
 
-ACCOUNT_ID = 'account_id1'
+ACCOUNT_ID = "account_id1"
 
 
-@pytest.fixture(name='mock_api')
+@pytest.fixture(name="mock_api")
 def mock_api():
     api = create_autospec(smarttub.SmartTub, instance=True)
     return api
