@@ -13,12 +13,15 @@ def lights(mock_api):
     spa = create_autospec(smarttub.Spa, instance=True)
     spa.request = mock_api.request
     lights = [
-        SpaLight(spa, **{
-            'color': {'blue': 0, 'green': 0, 'red': 0, 'white': 0},
-            'intensity': 0 if mode == SpaLight.LightMode.OFF else 50,
-            'mode': mode.name,
-            'zone': i + 1,
-        })
+        SpaLight(
+            spa,
+            **{
+                "color": {"blue": 0, "green": 0, "red": 0, "white": 0},
+                "intensity": 0 if mode == SpaLight.LightMode.OFF else 50,
+                "mode": mode.name,
+                "zone": i + 1,
+            }
+        )
         for i, mode in enumerate(SpaLight.LightMode)
     ]
     return lights
