@@ -13,12 +13,17 @@ def pumps(mock_api):
     spa = create_autospec(smarttub.Spa, instance=True)
     spa.request = mock_api.request
     pumps = [
-        SpaPump(spa, **{
-            'id': 'pid1',
-            'speed': 'speed1',
-            'state': 'OFF' if pump_type == SpaPump.PumpType.CIRCULATION else SpaPump.PumpState.HIGH.name,
-            'type': pump_type.name,
-        })
+        SpaPump(
+            spa,
+            **{
+                "id": "pid1",
+                "speed": "speed1",
+                "state": "OFF"
+                if pump_type == SpaPump.PumpType.CIRCULATION
+                else SpaPump.PumpState.HIGH.name,
+                "type": pump_type.name,
+            }
+        )
         for i, pump_type in enumerate(SpaPump.PumpType)
     ]
     return pumps
